# Input File Parser

The inpParser module provides functions that allow you to parse an Abaqus input file.

## Create input files

```{eval-rst}
.. autoclass:: abaqus.InputFileParser.InputFile.InputFile
    :noindex:
```

## Other Classes

```{eval-rst}

.. toggle::

    .. autoclass:: abaqus.InputFileParser.AbaqusNDarray.AbaqusNDarray
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.InputFileParser.InputFile.InputFile
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::

    .. autoclass:: abaqus.InputFileParser.Keyword.Keyword
        :members:
        :special-members: __init__
        :show-inheritance:

        .. autoclasstoc::
```
